require 'spec_helper'

describe 'forecast aggregate' do

  describe 'future_scheduled_hours_after' do
    it 'works' do
      cassette('aggregate-future_scheduled_hours_after') do
        x = forecast.aggregates.future_scheduled_hours_after("2016-11-29")

        expect(x.class).to be(Array)
        expect(x.first.class).to be(Forecast::Aggregate)
        expect(x.size > 1).to eq(true)
      end
    end

    it 'query by project_id' do
      cassette('aggregate-future_scheduled_hours-query-project_id') do
        x = forecast.aggregates.future_scheduled_hours_after("2016-11-29", {project_id: mm_forecast_project_id})

        expect(x.class).to be(Array)
        expect(x.first.class).to be(Forecast::Aggregate)
        expect_belong_to_one_project(x)
        expect(x.first.project_id).to eq(mm_forecast_project_id)

        expect(x.first.allocation).to eq(18.0)
      end
    end
  end

  describe 'remaining_budgeted_hours' do
    it 'works' do
      cassette('aggregate-remaining_budgeted_hours') do
        x = forecast.aggregates.remaining_budgeted_hours

        expect(x.class).to be(Array)
        expect(x.first.class).to be(Forecast::Aggregate)

        expect_belong_to_many_projects(x)
      end
    end

    it 'query by (forecast) project_id' do
      cassette('aggregate-remaining_budgeted_hours') do
        x = forecast.aggregates.remaining_budgeted_hours({project_id: mm_forecast_project_id})

        expect(x.class).to be(Array)
        expect(x.first.class).to be(Forecast::Aggregate)

        expect_belong_to_one_project(x)
      end
    end
  end

  def expect_belong_to_one_project(x)
    project_ids = x.collect(&:project_id)
    uniq_project_ids = project_ids.uniq
    expect(uniq_project_ids.size).to eq(1)
  end

  def expect_belong_to_many_projects(x)
    project_ids = x.collect(&:project_id)
    uniq_project_ids = project_ids.uniq
    expect(uniq_project_ids.size > 1).to eq(true)
  end

end
