require 'spec_helper'

describe 'forecast assignments' do

  describe 'all' do
    it 'works' do
      cassette('assignments-all') do
        assignments = forecast.assignments.all

        expect(assignments.class).to be(Array)
        expect(assignments.first.class).to be(Forecast::Assignment)
        expect(assignments.size > 1).to eq(true)
      end
    end

    it 'query by start_date' do
      cassette('assignments-query-start_date') do
        assignments = forecast.assignments.all({start_date: '2016-01-01'})

        expect(assignments.class).to be(Array)
        expect(assignments.first.class).to be(Forecast::Assignment)
        expect(assignments.size > 1).to eq(true)
      end
    end

    it 'query by end_date' do
      cassette('assignments-all-query-end_date') do
        assignments = forecast.assignments.all({end_date: '2017-01-01'})

        expect(assignments.class).to be(Array)
        expect(assignments.first.class).to be(Forecast::Assignment)
        expect(assignments.size > 1).to eq(true)
      end
    end

    it 'query by start_and end_date' do
      cassette('assignments-all-query-start_date-and-end_date') do
        assignments = forecast.assignments.all({start_date: '2016-01-01', end_date: '2017-01-01'})

        expect(assignments.class).to be(Array)
        expect(assignments.first.class).to be(Forecast::Assignment)
        expect(assignments.size > 1).to eq(true)
      end
    end

    it 'query by status' do
      cassette('assignments-all-query-status') do
        assignments = forecast.assignments.all({state: 'active'})

        expect(assignments.class).to be(Array)
        expect(assignments.first.class).to be(Forecast::Assignment)
        expect(assignments.size > 1).to eq(true)
      end
    end

    it 'query by project_id' do
      cassette('assignments-all-query-project_id') do
        x = forecast.assignments.all({project_id: mm_forecast_project_id})

        expect(x.class).to be(Array)
        expect(x.first.class).to be(Forecast::Assignment)
        expect(x.size > 1).to eq(true)

        expect_belong_to_one_project(x)
      end
    end
  end

  describe 'find' do
    it 'works' do
      cassette('assignments-find') do
        assignment_id = forecast.assignments.all.first.id
        assignment = forecast.assignments.find(assignment_id)

        expect(assignment.class).to be(Forecast::Assignment)
        expect(assignment.id > 1).to eq(true)
      end
    end
  end

  describe 'by_project' do
    it 'works' do
      cassette('assignments-by_project') do
        query = {
          start_date: "2016-01-01",
          end_date: "2018-01-01",
        }

        x = forecast.assignments.by_project(mm_forecast_project_id, query)

        expect(x.class).to be(Array)
        expect(x.first.class).to be(Forecast::Assignment)
        expect(x.size > 1).to eq(true)

        expect_belong_to_one_project(x)
      end
    end
  end

  describe 'last_by_project' do
    it 'works' do
      cassette('assignments-last_by_project') do
        x = forecast.assignments.last_by_project(mm_forecast_project_id)

        expect(x.class).to be(Forecast::Assignment)
        expect(x.project_id).to eq(mm_forecast_project_id)

        # manually checked it
        expect(x.end_date).to eq("2016-12-01")
      end
    end
  end

  describe 'sum_allocation_seconds' do
    it 'works' do
      cassette('assignments-sum_allocation_seconds') do
        query = {project_id: mm_forecast_project_id}

        x = forecast.assignments.sum_allocation_seconds(query)

        expect(x).to eq(62.0 * 3600)
      end
    end
  end

  def expect_belong_to_one_project(x)
      project_ids = x.collect(&:project_id)
      uniq_project_ids = project_ids.uniq
      expect(uniq_project_ids.size).to eq(1)
  end
end
